@@ -1,10 +1,7 @@
 # ABSTRACT: Read from a TAP archive and convert it for displaying
 
 package Archive::TAP::Convert;
-{
-  $Archive::TAP::Convert::VERSION = '0.006';
-}
-
+$Archive::TAP::Convert::VERSION = '0.007';
 use strict;
 use warnings;
 
@@ -25,23 +22,30 @@ sub convert_from_taparchive {
     # Set default values:
     die 'no archive specified'
         unless (exists $args{archive});
-    $args{formatter} = 'TAP::Formatter::HTML'
-        unless (exists $args{formatter});
-    $args{force_inline} = 0
-        unless (exists $args{force_inline});
 
-    # This is the complicate but flexible version to:
-    #   use TAP::Formatter::HTML;
-    #   my $formatter = TAP::Formatter::HTML->new;
     my $formatter;
-    (my $require_name = $args{formatter} . ".pm") =~ s{::}{/}g;
-    eval {
-        require $require_name;
-        $formatter = $args{formatter}->new();
-    };  
-    die "Problems with formatter $args{formatter}"
-      . " at $require_name: $@"
-        if $@;
+
+    if ( exists $args{formatter} && ref ( $args{formatter} ) =~ /^TAP::Formatter::/ ) {
+      $formatter = $args{formatter};
+    }
+    else {
+      $args{formatter} = 'TAP::Formatter::HTML'
+          unless (exists $args{formatter});
+      $args{force_inline} = 0
+          unless (exists $args{force_inline});
+
+      # This is the complicate but flexible version to:
+      #   use TAP::Formatter::HTML;
+      #   my $formatter = TAP::Formatter::HTML->new;
+      (my $require_name = $args{formatter} . ".pm") =~ s{::}{/}g;
+      eval {
+          require $require_name;
+          $formatter = $args{formatter}->new();
+      };
+      die "Problems with formatter $args{formatter}"
+        . " at $require_name: $@"
+          if $@;
+    }
 
     # if set, include all CSS and JS in HTML file
     if ($args{force_inline}) {
@@ -51,22 +55,22 @@ sub convert_from_taparchive {
 
     # Now we do a lot of magic to convert this stuff...
 
-    my $harness = TAP::Harness->new({ formatter => $formatter }); 
+    my $harness = TAP::Harness->new({ formatter => $formatter });
 
     $formatter->really_quiet(1);
     $formatter->prepare;
 
     my $session;
-    my $aggregator = TAP::Harness::Archive->aggregator_from_archive({ 
+    my $aggregator = TAP::Harness::Archive->aggregator_from_archive({
         archive          => $args{archive},
         parser_callbacks => {
             ALL => sub {
                 $session->result( $_[0] );
-            },  
-        },  
+            },
+        },
         made_parser_callback => sub {
             $session = $formatter->open_test( $_[1], $_[0] );
-        }   
+        }
     });
 
     $aggregator->start;
@@ -83,24 +87,39 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Archive::TAP::Convert - Read from a TAP archive and convert it for displaying
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
- use Archive::TAP::Convert qw(convert_from_taparchive);
+Either:
 
- my $html = convert_from_taparchive(
+  use Archive::TAP::Convert qw(convert_from_taparchive);
+
+  my $html = convert_from_taparchive(
                 archive   => '/must/be/the/complete/path/to/test.tar.gz',
                 formatter => 'TAP::Formatter::HTML',
-            );
+             );
 
-=encoding utf8
+Or:
+
+  use Archive::TAP::Convert qw(convert_from_taparchive);
+  use TAP::Formatter::HTML; # or ::JUnit, ::Console, etc.
+
+  my $formatter = TAP::Formatter::HTML->new;
+  # possibly configure formatter
+
+  my $html = convert_from_taparchive(
+                archive   => '/must/be/the/complete/path/to/test.tar.gz',
+                formatter => $formatter,
+             );
 
 =head1 ABOUT
 
@@ -115,7 +134,7 @@ The modul can be of help for you if you have TAP archives (e.g. created with C<p
 The method takes three arguments.
 Only C<archive> is required.
 It takes the B<full> path to your TAP archive.
-The C<formatter> defaults to C<TAP::Formatter::HTML>, but you can give any other formatter.
+The C<formatter> defaults to C<TAP::Formatter::HTML>, but you can define any other formatter by string or even pass a reference to an existing formatter-object.
 The method will return the content of the TAP archive, parsed according to the formatter you have specified.
 
  my $html = convert_from_taparchive(
@@ -153,13 +172,23 @@ Available formatters: L<TAP::Formatter::Base> and its implementations for L<HTML
 
 =back
 
+=head1 CONTRIBUTORS
+
+=over
+
+=item *
+
+Xavier Caron (XAV / maspalio)
+
+=back
+
 =head1 AUTHOR
 
 Boris Däppen <bdaeppen.perl@gmail.com>, Renée Bäcker <module@renee-baecker.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Boris Däppen, Renée Bäcker, plusW.
+This software is copyright (c) 2014 by Boris Däppen, Renée Bäcker, plusW.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
